##  Setting Due Dates for Survey Completion
To improve survey management and efficiency, you have the option to set due dates for each survey that you create. This helps drive participation as it limits the amount of time available for users to submit a response.
To set a due date for a survey, do the following:
  1. Select the option **Automatically close survey on specified date**.
  2. Select the desired due date using the date picker. By default, the system sets the due date to 28 calendar days from the current date.


The survey invitation email displays the due date to inform participants of the deadline. After the due date passes, the survey status automatically changes to ‘Finished’, and participants can no longer submit responses. If you need more time to collect responses, you can extend the due date by restarting the finished survey and setting a new due date during the restart.
If you want to change or extend the due date for an unfinished survey, you must first manually finish it, then restart it and set the new due date during the restart process.
To learn more about restarting surveys, see [Restarting a Survey](https://help.sap.com/docs/leanix/ea/managing-surveys-and-viewing-results?locale=en-US&state=PRODUCTION&version=CLOUD#loio275b09857a441014b84ad3cdb74f9fc5__restarting_a_survey). To learn about manually finishing a survey, see [Finishing a Survey](https://help.sap.com/docs/leanix/ea/managing-surveys-and-viewing-results?locale=en-US&state=PRODUCTION&version=CLOUD#loio275b09857a441014b84ad3cdb74f9fc5__finishing_a_survey).
